@@ -17,6 +17,7 @@
 #
 # Refer to the README and COPYING files for full details of the license
 #
+
 from __future__ import absolute_import
 
 import errno
@@ -31,7 +32,8 @@ from collections import defaultdict
 
 from yajsonrpc.betterAsyncore import Reactor
 from yajsonrpc.exception import JsonRpcBindingsError
-from yajsonrpc.stompreactor import StompClient, StompRpcServer
+from yajsonrpc.stompclient import StompClient
+from yajsonrpc.stompserver import StompRpcServer
 from yajsonrpc import Notification
 from vdsm import sslutils
 from vdsm.config import config
@@ -118,7 +120,8 @@ class clientIF(object):
             self.lastRemoteAccess = 0
             self._enabled = True
             self._netConfigDirty = False
-            self._prepareMOM()
+            self.mom = MomClient(config.get("mom", "socket_path"))
+            self.mom.connect()
             secret.clear()
             concurrent.thread(self._recoverThread, name='vmrecovery').start()
             self.channelListener.settimeout(
@@ -310,7 +313,7 @@ class clientIF(object):
             try:
                 from vdsm.rpc import Bridge
                 from vdsm.rpc.bindingjsonrpc import BindingJsonRpc
-                from yajsonrpc.stompreactor import StompDetector
+                from yajsonrpc.stompserver import StompDetector
             except ImportError:
                 self.log.warn('Unable to load the json rpc server module. '
                               'Please make sure it is installed.')
@@ -324,11 +327,6 @@ class clientIF(object):
                 stomp_detector = StompDetector(json_binding)
                 self._acceptor.add_detector(stomp_detector)
 
-    def _prepareMOM(self):
-        momconf = config.get("mom", "conf")
-
-        self.mom = MomClient(momconf)
-
     def _wait_for_shutting_down_vms(self):
         """
         Wait loop checking remaining VMs in vm container
