@@ -15,6 +15,7 @@
 # Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
 
 from __future__ import absolute_import
+from __future__ import division
 from functools import partial
 
 import logging
@@ -330,6 +331,7 @@ command_info = {
     'Host_getAllTasksStatuses': {'ret': 'allTasksStatus'},
     'Host_getCapabilities': {'ret': Host_getCapabilities_Ret},
     'Host_getNetworkCapabilities': {'ret': 'info'},
+    'Host_getNetworkStatistics': {'ret': 'info'},
     'Host_getConnectedStoragePools': {'ret': 'poollist'},
     'Host_getDeviceList': {'ret': 'devList'},
     'Host_getDevicesVisibility': {'ret': 'visible'},
