@@ -61,7 +61,6 @@ from vdsm.storage import sd
 from vdsm.storage.compat import sanlock
 from vdsm.storage.mailbox import MAILBOX_SIZE
 from vdsm.storage.persistent import PersistentDict, DictValidator
-from vdsm.storage.sdm import volume_artifacts
 
 import vdsm.common.supervdsm as svdsm
 
@@ -668,9 +667,6 @@ class BlockStorageDomainManifest(sd.StorageDomainManifest):
         """
         return blockVolume.BlockVolumeManifest
 
-    def get_volume_artifacts(self, img_id, vol_id):
-        return volume_artifacts.BlockVolumeArtifacts(self, img_id, vol_id)
-
     def _getImgExclusiveVols(self, imgUUID, volsImgs):
         """Filter vols belonging to imgUUID only."""
         exclusives = dict((vName, v) for vName, v in volsImgs.iteritems()
@@ -1012,13 +1008,16 @@ class BlockStorageDomain(sd.StorageDomain):
     @classmethod
     def create(cls, sdUUID, domainName, domClass, vgUUID, storageType,
                version):
-        """ Create new storage domain
-            'sdUUID' - Storage Domain UUID
-            'domainName' - storage domain name
-            'domClass' - Data/Iso
-            'vgUUID' - volume group UUID
-            'storageType' - NFS_DOMAIN, LOCALFS_DOMAIN, &etc.
-            'version' - DOMAIN_VERSIONS
+        """
+        Create new storage domain
+
+        Arguments:
+            sdUUID (UUID): Storage Domain UUID
+            domainName (str): Storage domain name
+            domClass (int): Data/Iso
+            vgUUID (UUID): volume group UUID
+            storageType (int): ISCSI_DOMAIN, FCP_DOMAIN, &etc.
+            version (int): DOMAIN_VERSIONS,
         """
         cls.log.info("sdUUID=%s domainName=%s domClass=%s vgUUID=%s "
                      "storageType=%s version=%s", sdUUID, domainName, domClass,
