@@ -27,6 +27,7 @@ from vdsm import constants
 from vdsm import utils
 from vdsm.common import exception
 from vdsm.common.commands import grepCmd
+from vdsm.common.compat import glob_escape
 from vdsm.common.marks import deprecated
 from vdsm.common.threadlocal import vars
 from vdsm.storage import constants as sc
@@ -204,13 +205,13 @@ class FileVolumeManifest(volume.VolumeManifest):
         volPath = self.getVolumePath()
         return int(int(self.oop.os.stat(volPath).st_size) / bs)
 
-    def getVolumeTrueSize(self, bs=BLOCK_SIZE):
+    def getVolumeTrueSize(self):
         """
-        Return the size of the storage allocated for this volume
+        Return the in bytes size of the storage allocated for this volume
         on underlying storage
         """
         volPath = self.getVolumePath()
-        return int(int(self.oop.os.stat(volPath).st_blocks) * BLOCK_SIZE / bs)
+        return int(int(self.oop.os.stat(volPath).st_blocks) * BLOCK_SIZE)
 
     def setMetadata(self, meta, metaId=None):
         """
@@ -330,7 +331,7 @@ class FileVolumeManifest(volume.VolumeManifest):
         """
         sd = sdCache.produce_manifest(sdUUID)
         img_dir = sd.getImageDir(imgUUID)
-        pattern = os.path.join(img_dir, "*.meta")
+        pattern = os.path.join(glob_escape(img_dir), "*.meta")
         files = oop.getProcessPool(sdUUID).glob.glob(pattern)
         volList = []
         for i in files:
